@@ -44,62 +44,62 @@ pub struct SubmitRunRequest {
     pub validation: String,
     pub is_replay: bool,
     pub prohibited_mods: bool,
-    pub game_states: Vec<GameState>,
+    pub game_data: GameState,
     pub status: i32,
     pub replay_data: String,
     pub replay_player_id: i32,
 }
 
-#[derive(serde::Serialize, Debug)]
+#[derive(serde::Serialize, Debug, Default)]
 #[serde(rename_all = "camelCase")]
 pub struct GameState {
-    pub gems_collected: i32,
-    pub enemies_killed: i32,
-    pub daggers_fired: i32,
-    pub daggers_hit: i32,
-    pub enemies_alive: i32,
-    pub homing_daggers: i32,
-    pub homing_daggers_eaten: i32,
-    pub gems_despawned: i32,
-    pub gems_eaten: i32,
-    pub gems_total: i32,
-    pub skull1s_alive: i32,
-    pub skull2s_alive: i32,
-    pub skull3s_alive: i32,
-    pub spiderlings_alive: i32,
-    pub skull4s_alive: i32,
-    pub squid1s_alive: i32,
-    pub squid2s_alive: i32,
-    pub squid3s_alive: i32,
-    pub centipedes_alive: i32,
-    pub gigapedes_alive: i32,
-    pub spider1s_alive: i32,
-    pub spider2s_alive: i32,
-    pub leviathans_alive: i32,
-    pub orbs_alive: i32,
-    pub thorns_alive: i32,
-    pub ghostpedes_alive: i32,
-    pub skull1s_killed: i32,
-    pub skull2s_killed: i32,
-    pub skull3s_killed: i32,
-    pub spiderlings_killed: i32,
-    pub skull4s_killed: i32,
-    pub squid1s_killed: i32,
-    pub squid2s_killed: i32,
-    pub squid3s_killed: i32,
-    pub centipedes_killed: i32,
-    pub gigapedes_killed: i32,
-    pub spider1s_killed: i32,
-    pub spider2s_killed: i32,
-    pub leviathans_killed: i32,
-    pub orbs_killed: i32,
-    pub thorns_killed: i32,
-    pub ghostpedes_killed: i32,
+    pub gems_collected: Vec<i32>,
+    pub enemies_killed: Vec<i32>,
+    pub daggers_fired: Vec<i32>,
+    pub daggers_hit: Vec<i32>,
+    pub enemies_alive: Vec<i32>,
+    pub homing_daggers: Vec<i32>,
+    pub homing_daggers_eaten: Vec<i32>,
+    pub gems_despawned: Vec<i32>,
+    pub gems_eaten: Vec<i32>,
+    pub gems_total: Vec<i32>,
+    pub skull1s_alive: Vec<i32>,
+    pub skull2s_alive: Vec<i32>,
+    pub skull3s_alive: Vec<i32>,
+    pub spiderlings_alive: Vec<i32>,
+    pub skull4s_alive: Vec<i32>,
+    pub squid1s_alive: Vec<i32>,
+    pub squid2s_alive: Vec<i32>,
+    pub squid3s_alive: Vec<i32>,
+    pub centipedes_alive: Vec<i32>,
+    pub gigapedes_alive: Vec<i32>,
+    pub spider1s_alive: Vec<i32>,
+    pub spider2s_alive: Vec<i32>,
+    pub leviathans_alive: Vec<i32>,
+    pub orbs_alive: Vec<i32>,
+    pub thorns_alive: Vec<i32>,
+    pub ghostpedes_alive: Vec<i32>,
+    pub skull1s_killed: Vec<i32>,
+    pub skull2s_killed: Vec<i32>,
+    pub skull3s_killed: Vec<i32>,
+    pub spiderlings_killed: Vec<i32>,
+    pub skull4s_killed: Vec<i32>,
+    pub squid1s_killed: Vec<i32>,
+    pub squid2s_killed: Vec<i32>,
+    pub squid3s_killed: Vec<i32>,
+    pub centipedes_killed: Vec<i32>,
+    pub gigapedes_killed: Vec<i32>,
+    pub spider1s_killed: Vec<i32>,
+    pub spider2s_killed: Vec<i32>,
+    pub leviathans_killed: Vec<i32>,
+    pub orbs_killed: Vec<i32>,
+    pub thorns_killed: Vec<i32>,
+    pub ghostpedes_killed: Vec<i32>,
 }
 
 impl SubmitRunRequest {
     pub fn from_compiled_run<T: ToString, K: ToString>(
-        run: std::sync::Arc<StatsBlockWithFrames>, 
+        run: std::sync::Arc<StatsBlockWithFrames>,
         secrets: Option<DdclSecrets>, 
         client: T, 
         version: K,
@@ -109,52 +109,51 @@ impl SubmitRunRequest {
             bail!("Missing DDCL Secrets");
         }
 
-        let states: Vec<GameState> = run.frames.iter().map(|frame| {
-            GameState {
-                gems_collected: frame.gems_collected,
-                enemies_killed: frame.kills,
-                daggers_fired: frame.daggers_fired,
-                daggers_hit: frame.daggers_hit,
-                enemies_alive: frame.enemies_alive,
-                homing_daggers: frame.homing,
-                homing_daggers_eaten: frame.daggers_eaten,
-                gems_despawned: frame.gems_despawned,
-                gems_eaten: frame.gems_eaten,
-                gems_total: frame.gems_total,
-                skull1s_alive: frame.per_enemy_alive_count[0] as i32,
-                skull2s_alive: frame.per_enemy_alive_count[1] as i32,
-                skull3s_alive: frame.per_enemy_alive_count[2] as i32,
-                spiderlings_alive: frame.per_enemy_alive_count[3] as i32,
-                skull4s_alive: frame.per_enemy_alive_count[4] as i32,
-                squid1s_alive: frame.per_enemy_alive_count[5] as i32,
-                squid2s_alive: frame.per_enemy_alive_count[6] as i32,
-                squid3s_alive: frame.per_enemy_alive_count[7] as i32,
-                centipedes_alive: frame.per_enemy_alive_count[8] as i32,
-                gigapedes_alive: frame.per_enemy_alive_count[9] as i32,
-                spider1s_alive: frame.per_enemy_alive_count[10] as i32,
-                spider2s_alive: frame.per_enemy_alive_count[11] as i32,
-                leviathans_alive: frame.per_enemy_alive_count[12] as i32,
-                orbs_alive: frame.per_enemy_alive_count[13] as i32,
-                thorns_alive: frame.per_enemy_alive_count[14] as i32,
-                ghostpedes_alive: frame.per_enemy_alive_count[15] as i32,
-                skull1s_killed: frame.per_enemy_kill_count[0] as i32,
-                skull2s_killed: frame.per_enemy_kill_count[1] as i32,
-                skull3s_killed: frame.per_enemy_kill_count[2] as i32,
-                spiderlings_killed: frame.per_enemy_kill_count[3] as i32,
-                skull4s_killed: frame.per_enemy_kill_count[4] as i32,
-                squid1s_killed: frame.per_enemy_kill_count[5] as i32,
-                squid2s_killed: frame.per_enemy_kill_count[6] as i32,
-                squid3s_killed: frame.per_enemy_kill_count[7] as i32,
-                centipedes_killed: frame.per_enemy_kill_count[8] as i32,
-                gigapedes_killed: frame.per_enemy_kill_count[9] as i32,
-                spider1s_killed: frame.per_enemy_kill_count[10] as i32,
-                spider2s_killed: frame.per_enemy_kill_count[11] as i32,
-                leviathans_killed: frame.per_enemy_kill_count[12] as i32,
-                orbs_killed: frame.per_enemy_kill_count[13] as i32,
-                thorns_killed: frame.per_enemy_kill_count[14] as i32,
-                ghostpedes_killed: frame.per_enemy_kill_count[15] as i32,
-            }
-        }).collect();
+        let game_data = GameState {
+            gems_collected: run.frames.iter().map(|f| f.gems_collected).collect(),
+            enemies_killed: run.frames.iter().map(|f| f.kills).collect(),
+            daggers_fired: run.frames.iter().map(|f| f.daggers_fired).collect(),
+            daggers_hit: run.frames.iter().map(|f| f.daggers_hit).collect(),
+            enemies_alive: run.frames.iter().map(|f| f.enemies_alive).collect(),
+            homing_daggers: run.frames.iter().map(|f| f.homing).collect(),
+            homing_daggers_eaten: run.frames.iter().map(|f| f.daggers_eaten).collect(),
+            gems_despawned: run.frames.iter().map(|f| f.gems_despawned).collect(),
+            gems_eaten: run.frames.iter().map(|f| f.gems_eaten).collect(),
+            gems_total: run.frames.iter().map(|f| f.gems_total).collect(),
+            skull1s_alive: run.frames.iter().map(|f| f.per_enemy_alive_count[0] as i32).collect(),
+            skull2s_alive: run.frames.iter().map(|f| f.per_enemy_alive_count[1] as i32).collect(),
+            skull3s_alive: run.frames.iter().map(|f| f.per_enemy_alive_count[2] as i32).collect(),
+            spiderlings_alive: run.frames.iter().map(|f| f.per_enemy_alive_count[3] as i32).collect(),
+            skull4s_alive: run.frames.iter().map(|f| f.per_enemy_alive_count[4] as i32).collect(),
+            squid1s_alive: run.frames.iter().map(|f| f.per_enemy_alive_count[5] as i32).collect(),
+            squid2s_alive: run.frames.iter().map(|f| f.per_enemy_alive_count[6] as i32).collect(),
+            squid3s_alive: run.frames.iter().map(|f| f.per_enemy_alive_count[7] as i32).collect(),
+            centipedes_alive: run.frames.iter().map(|f| f.per_enemy_alive_count[8] as i32).collect(),
+            gigapedes_alive: run.frames.iter().map(|f| f.per_enemy_alive_count[9] as i32).collect(),
+            spider1s_alive: run.frames.iter().map(|f| f.per_enemy_alive_count[10] as i32).collect(),
+            spider2s_alive: run.frames.iter().map(|f| f.per_enemy_alive_count[11] as i32).collect(),
+            leviathans_alive: run.frames.iter().map(|f| f.per_enemy_alive_count[12] as i32).collect(),
+            orbs_alive: run.frames.iter().map(|f| f.per_enemy_alive_count[13] as i32).collect(),
+            thorns_alive: run.frames.iter().map(|f| f.per_enemy_alive_count[14] as i32).collect(),
+            ghostpedes_alive: run.frames.iter().map(|f| f.per_enemy_alive_count[15] as i32).collect(),
+            skull1s_killed: run.frames.iter().map(|f| f.per_enemy_kill_count[0] as i32).collect(),
+            skull2s_killed: run.frames.iter().map(|f| f.per_enemy_kill_count[1] as i32).collect(),
+            skull3s_killed: run.frames.iter().map(|f| f.per_enemy_kill_count[2] as i32).collect(),
+            spiderlings_killed: run.frames.iter().map(|f| f.per_enemy_kill_count[3] as i32).collect(),
+            skull4s_killed: run.frames.iter().map(|f| f.per_enemy_kill_count[4] as i32).collect(),
+            squid1s_killed: run.frames.iter().map(|f| f.per_enemy_kill_count[5] as i32).collect(),
+            squid2s_killed: run.frames.iter().map(|f| f.per_enemy_kill_count[6] as i32).collect(),
+            squid3s_killed: run.frames.iter().map(|f| f.per_enemy_kill_count[7] as i32).collect(),
+            centipedes_killed: run.frames.iter().map(|f| f.per_enemy_kill_count[8] as i32).collect(),
+            gigapedes_killed: run.frames.iter().map(|f| f.per_enemy_kill_count[9] as i32).collect(),
+            spider1s_killed: run.frames.iter().map(|f| f.per_enemy_kill_count[10] as i32).collect(),
+            spider2s_killed: run.frames.iter().map(|f| f.per_enemy_kill_count[11] as i32).collect(),
+            leviathans_killed: run.frames.iter().map(|f| f.per_enemy_kill_count[12] as i32).collect(),
+            orbs_killed: run.frames.iter().map(|f| f.per_enemy_kill_count[13] as i32).collect(),
+            thorns_killed: run.frames.iter().map(|f| f.per_enemy_kill_count[14] as i32).collect(),
+            ghostpedes_killed: run.frames.iter().map(|f| f.per_enemy_kill_count[15] as i32).collect(),
+        };
+
         let sec = secrets.unwrap();
         let last = run.frames.last().unwrap();
 
@@ -211,7 +210,7 @@ impl SubmitRunRequest {
             validation: validation.replace('=', ""),
             is_replay: run.block.is_replay,
             prohibited_mods: run.block.prohibited_mods,
-            game_states: states,
+            game_data,
             status: run.block.status,
             replay_data: replay_bin,
             replay_player_id: run.block.replay_player_id,
